import { ExtendedProperties } from './ExtendedProperties';
import { Time } from './Time';
import { Conference } from './Conference';
export interface EventCreateOrUpdate {
    start: Time;
    end: Time;
    /**
     * File attachments for the event. Currently only Google Drive attachments are supported.
     * In order to modify attachments the supportsAttachments request parameter should be set to true.
     *
     * There can be at most 25 attachments per event.
     */
    attachments?: {
        /**
         * URL link to the attachment.
         * For adding Google Drive file attachments use the same format as in alternateLink property of the Files resource in the Drive API.
         * Required when adding an attachment.
         */
        fileUrl: string;
    }[];
    /**
     * The attendees of the event. See the Events with attendees guide for more information on scheduling events with other calendar users. Service accounts need to use domain-wide delegation of authority to populate the attendee list.
     */
    attendees?: {
        /**
         * The attendee's email address, if available. This field must be present when adding an attendee. It must be a valid email address as per RFC5322.
         * Required when adding an attendee.
         */
        email: string;
        /**
         * The attendee's name, if available. Optional.
         */
        displayName?: string;
        /**
         * Whether the attendee is a resource. Can only be set when the attendee is added to the event for the first time. Subsequent modifications are ignored. Optional. The default is False.
         */
        resource?: boolean;
        /**
         * Whether this is an optional attendee. Optional. The default is False.
         */
        optional?: boolean;
        /**
         * The attendee's response status. Possible values are:
         ** "needsAction" - The attendee has not responded to the invitation.
         ** "declined" - The attendee has declined the invitation.
         ** "tentative" - The attendee has tentatively accepted the invitation.
         ** "accepted" - The attendee has accepted the invitation.
         */
        responseStatus?: 'needsAction' | 'declined' | 'tentative' | 'accepted';
        /**
         * The attendee's response comment. Optional.
         */
        comment?: string;
        /**
         * Number of additional guests. Optional. The default is 0.
         */
        additionalGuests?: number;
    }[];
    /**
     * The color of the event. This is an ID referring to an entry in the event section of the colors definition (see the colors endpoint). Optional.
     */
    colorId?: string;
    /**
     * The conference-related information, such as details of a Google Meet conference. To create new conference details use the createRequest field. To persist your changes, remember to set the conferenceDataVersion request parameter to 1 for all event modification requests.
     */
    conferenceData?: Conference;
    /**
     * Description of the event. Can contain HTML. Optional.
     */
    description?: string;
    /**
     * Extended properties of the event.
     */
    extendedProperties?: ExtendedProperties;
    /**
     * Whether attendees other than the organizer can invite others to the event. Optional. The default is True.
     */
    guestsCanInviteOthers?: boolean;
    /**
     * Whether attendees other than the organizer can modify the event. Optional. The default is False.
     */
    guestsCanModify?: boolean;
    /**
     * Whether attendees other than the organizer can see who the event's attendees are. Optional. The default is True.
     */
    guestsCanSeeOtherGuests?: boolean;
    /**
     * Opaque identifier of the event. When creating new single or recurring events, you can specify their IDs. Provided IDs must follow these rules:
     ** characters allowed in the ID are those used in base32hex encoding, i.e. lowercase letters a-v and digits 0-9, see section 3.1.2 in RFC2938
     ** the length of the ID must be between 5 and 1024 characters
     ** the ID must be unique per calendar
     *
     * Due to the globally distributed nature of the system, we cannot guarantee that ID collisions will be detected at event creation time. To minimize the risk of collisions we recommend using an established UUID algorithm such as one described in RFC4122.
     *
     * If you do not specify an ID, it will be automatically generated by the server.
     *
     * Note that the icalUID and the id are not identical and only one of them should be supplied at event creation time. One difference in their semantics is that in recurring events, all occurrences of one event have different ids while they all share the same icalUIDs.
     */
    id?: string;
    /**
     * Geographic location of the event as free-form text. Optional.
     */
    location?: string;
    /**
     * For an instance of a recurring event, this is the time at which this event would start according to the recurrence data in the recurring event identified by recurringEventId. It uniquely identifies the instance within the recurring event series even if the instance was moved to a different time. Immutable.
     */
    originalStartTime?: Time;
    /**
     * List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event, as specified in RFC5545. Note that DTSTART and DTEND lines are not allowed in this field; event start and end times are specified in the start and end fields. This field is omitted for single events or instances of recurring events.
     */
    recurrence?: string[];
    /**
     * Information about the event's reminders for the authenticated user.
     */
    reminders?: {
        /**
         * Whether the default reminders of the calendar apply to the event.
         */
        useDefault?: boolean;
        /**
         * If the event doesn't use the default reminders, this lists the reminders specific to the event, or, if not set, indicates that no reminders are set for this event. The maximum number of override reminders is 5.
         */
        overrides?: {
            /**
             * The method used by this reminder. Possible values are:
             ** "email" - Reminders are sent via email.
             ** "popup" - Reminders are sent via a UI popup.
             *
             * Required when adding a reminder.
             */
            method: 'email' | 'popup';
            /**
             * Number of minutes before the start of the event when the reminder should trigger. Valid values are between 0 and 40320 (4 weeks in minutes).
             * Required when adding a reminder.
             */
            minutes: number;
        }[];
    };
    /**
     * Sequence number as per iCalendar.
     */
    sequence?: number;
    /**
     * Source from which the event was created. For example, a web page, an email message or any document identifiable by an URL with HTTP or HTTPS scheme. Can only be seen or modified by the creator of the event.
     */
    source?: {
        /**
         * URL of the source pointing to a resource. The URL scheme must be HTTP or HTTPS.
         */
        url: string;
        /**
         * Title of the source; for example a title of a web page or an email subject.
         */
        title?: string;
    };
    /**
     * Status of the event. Optional. Possible values are:
     ** "confirmed" - The event is confirmed. This is the default status.
     ** "tentative" - The event is tentatively confirmed.
     ** "cancelled" - The event is cancelled (deleted). The list method returns cancelled events only on incremental sync (when syncToken or updatedMin are specified) or if the showDeleted flag is set to true. The get method always returns them.
     *
     * A cancelled status represents two different states depending on the event type:
     ** Cancelled exceptions of an uncancelled recurring event indicate that this instance should no longer be presented to the user. Clients should store these events for the lifetime of the parent recurring event.
     * Cancelled exceptions are only guaranteed to have values for the id, recurringEventId and originalStartTime fields populated. The other fields might be empty.
     ** All other cancelled events represent deleted events. Clients should remove their locally synced copies. Such cancelled events will eventually disappear, so do not rely on them being available indefinitely.
     * Deleted events are only guaranteed to have the id field populated.
     *
     * On the organizer's calendar, cancelled events continue to expose event details (summary, location, etc.) so that they can be restored (undeleted). Similarly, the events to which the user was invited and that they manually removed continue to provide details. However, incremental sync requests with showDeleted set to false will not return these details.
     *
     * If an event changes its organizer (for example via the move operation) and the original organizer is not on the attendee list, it will leave behind a cancelled event where only the id field is guaranteed to be populated.
     */
    status?: 'confirmed' | 'tentative' | 'cancelled';
    /**
     * Title of the event.
     */
    summary?: string;
    /**
     * Whether the event blocks time on the calendar. Optional. Possible values are:
     ** "opaque" - Default value. The event does block time on the calendar. This is equivalent to setting Show me as to Busy in the Calendar UI.
     ** "transparent" - The event does not block time on the calendar. This is equivalent to setting Show me as to Available in the Calendar UI.
     */
    transparency?: 'opaque' | 'transparent';
    /**
     * Visibility of the event. Optional. Possible values are:
     ** "default" - Uses the default visibility for events on the calendar. This is the default value.
     ** "public" - The event is public and event details are visible to all readers of the calendar.
     ** "private" - The event is private and only event attendees may view event details.
     ** "confidential" - The event is private. This value is provided for compatibility reasons.
     */
    visibility?: 'default' | 'public' | 'private' | 'confidential';
}
//# sourceMappingURL=EventCreateOrUpdate.d.ts.map