/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Response, Request, BaseApiCore, constructHeaders, constructUrl, executeHttpCall } from '@managed-api/commons-core';
import { errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
;
export class GoogleCalendarApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.CalendarList = new CalendarListGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Event = new EventGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.CalendarList, this.Event);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options) !== null && _a !== void 0 ? _a : {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(CalendarList, Event) {
        this.CalendarList = CalendarList;
        this.Event = Event;
    }
    /**
     * Returns the calendars on the user's calendar list.
     * Alternative usage: CalendarList.getCalendarsFromCalendarList
     * Documentation: https://developers.google.com/calendar/v3/reference/calendarList/list
     * @param options Request options.
     */
    async getCalendarsFromCalendarList(options) {
        return this.CalendarList.getCalendarsFromCalendarList(options);
    }
    /**
     * Deletes an event.
     * Alternative usage: Event.deleteEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/delete
     * @param options Request options.
     */
    async deleteEvent(options) {
        return this.Event.deleteEvent(options);
    }
    /**
     * Returns an event.
     * Alternative usage: Event.getEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/get
     * @param options Request options.
     */
    async getEvent(options) {
        return this.Event.getEvent(options);
    }
    /**
     * Creates an event.
     * Alternative usage: Event.createEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/insert
     * @param options Request options.
     */
    async createEvent(options) {
        return this.Event.createEvent(options);
    }
    /**
     * Returns events on the specified calendar.
     * Alternative usage: Event.getEvents
     * Documentation: https://developers.google.com/calendar/v3/reference/events/list
     * @param options Request options.
     */
    async getEvents(options) {
        return this.Event.getEvents(options);
    }
    /**
     * Updates an event.
     * Alternative usage: Event.updateEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/update
     * @param options Request options.
     */
    async updateEvent(options) {
        return this.Event.updateEvent(options);
    }
}
class CalendarListGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns the calendars on the user's calendar list.
     * Documentation: https://developers.google.com/calendar/v3/reference/calendarList/list
     * @param options Request options.
     */
    async getCalendarsFromCalendarList(options) {
        const { maxResults, minAccessRole, pageToken, showDeleted, showHidden, syncToken, headers, errorStrategy } = options || {};
        const queryParams = { syncToken, showDeleted, pageToken, maxResults, minAccessRole, showHidden };
        const request = new Request('GET', constructUrl('/calendar/v3/users/me/calendarList', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class EventGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Deletes an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/delete
     * @param options Request options.
     */
    async deleteEvent(options) {
        const { calendarId, eventId, sendUpdates, headers, errorStrategy } = options;
        const queryParams = { sendUpdates };
        const request = new Request('DELETE', constructUrl(`/calendar/v3/calendars/${encodeURIComponent(calendarId)}/events/${encodeURIComponent(eventId)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/get
     * @param options Request options.
     */
    async getEvent(options) {
        const { calendarId, eventId, maxAttendees, timeZone, headers, errorStrategy } = options;
        const queryParams = { maxAttendees, timeZone };
        const request = new Request('GET', constructUrl(`/calendar/v3/calendars/${encodeURIComponent(calendarId)}/events/${encodeURIComponent(eventId)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/insert
     * @param options Request options.
     */
    async createEvent(options) {
        const { calendarId, conferenceDataVersion, sendUpdates, supportsAttachments, maxAttendees, body, headers, errorStrategy } = options;
        const queryParams = { maxAttendees, sendUpdates, conferenceDataVersion, supportsAttachments };
        const request = new Request('POST', constructUrl(`/calendar/v3/calendars/${encodeURIComponent(calendarId)}/events`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns events on the specified calendar.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/list
     * @param options Request options.
     */
    async getEvents(options) {
        const { calendarId, iCalUID, maxResults, orderBy, showHiddenInvitations, singleEvents, syncToken, timeMax, timeMin, timeZone, updatedMin, maxAttendees, pageToken, privateExtendedProperty, q, sharedExtendedProperty, showDeleted, headers, errorStrategy } = options;
        const queryParams = { maxAttendees, timeZone, iCalUID, maxResults, orderBy, pageToken, privateExtendedProperty, q, sharedExtendedProperty, showDeleted, showHiddenInvitations, singleEvents, syncToken, timeMax, timeMin, updatedMin };
        const request = new Request('GET', constructUrl(`/calendar/v3/calendars/${encodeURIComponent(calendarId)}/events`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/update
     * @param options Request options.
     */
    async updateEvent(options) {
        const { calendarId, body, eventId, conferenceDataVersion, maxAttendees, sendUpdates, supportsAttachments, headers, errorStrategy } = options;
        const queryParams = { maxAttendees, supportsAttachments, conferenceDataVersion, sendUpdates };
        const request = new Request('PUT', constructUrl(`/calendar/v3/calendars/${encodeURIComponent(calendarId)}/events/${encodeURIComponent(eventId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
